/***** interface.c ************************************************
 * Description: Routine for gathering arguments from the command
 *              line.
 * Author: Bernhard Haubold, haubold@evolbio.mpg.de
 * Date: Sun Jun 20 13:12:10 2004.
 *****************************************************************/
#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include "interface.h"
#include "eprintf.h"

Args *args;

Args *getArgs(int argc, char *argv[]){
  char c;
  char *optString = "hvdn:s:p:";

  args = (Args *)emalloc(sizeof(Args));

  args->n = -1;
  args->s = -1;
  args->p = -1;
  args->d = 0;
  args->h = 0;
  args->e = 0;

  c = getopt(argc, argv, optString);
  while(c != -1){
    switch(c){
    case 'd':                           /* debugging information? */
      args->d = 1;
      break;
    case 'v':                           /* version information? */
      args->v = 1;
      break;
    case 'n':                           /* sample size */
      args->n = atoi(optarg);
      break;
    case 's':                           /* number of segregating sites */
      args->s = atof(optarg);
      break;
    case 'p':                           /* pi */
      args->p = atof(optarg);
      break;
    case '?':                           /* fall-through is intentional */
    case 'h':                           /* print help */
      args->h = 1;
      break;
    default:
      printf("# unknown argument: %c\n",c);
      args->e = 1;
      return args;
    }
    c = getopt(argc, argv, optString);
  }
  if(args->n == -1 || args->s == -1 || args->p == -1)
    args->e = 1;
  return args;
}

void printUsage(char *version){
  printf("Usage: %s [options]\n",progname());
  printf("Compute Tajima's D\n");
  printf("td -n 10 -s 20 -p 5.4\n");
  printf("Options:\n");
  printf("\t-n <NUM> sample size\n");
  printf("\t-s <NUM> number of segregating sites\n");
  printf("\t-p <NUM> average number of pairwise mismatches\n");
  printf("\t[-h print this help message and exit]\n");
  printf("\t[-v print program information and exit]\n");
  exit(0);
}

void printSplash(char *version){
  printf("%s %s\n",progname(),version);
  printf("Written by Bernhard Haubold.\n");
  printf("Distributed under the GNU General Public License.\n");
  printf("Please send bug reports to haubold@evolbio.mpg.de\n");
  exit(0);
}
