/***** td.c ***************************************
 * Description: Compute Tajima's D.
 * Reference: Tajima, F. (1989). Statistical method
 *    for testing the neutral mutation hypothesis
 *    by DNA polymorphism. Genetics, 123:585-595.
 * Author: Bernhard Haubold, haubold@evolbio.mpg.de
 * Date: Wed Jun  8 12:49:56 2011
 **************************************************/
#include <stdio.h>
#include "tajd.h"
#include "eprintf.h"
#include "interface.h"

int main(int argc, char *argv[]){
  Args *args;
  char *version;
  double td, a1, a2, b1, b2, c1, c2, e1, e2;

  version = "0.3";
  setprogname2("td");
  args = getArgs(argc, argv);

  if(args->v)
    printSplash(version);
  if(args->h || args->e)
    printUsage(version);
  td = tajd(args->n, args->s, args->p);
  printf("Tajima's D: %f\n",td);
  if(args->d){
    a1 = a1f(args->n);
    a2 = a2f(args->n);
    b1 = b1f(args->n);
    b2 = b2f(args->n);
    c1 = c1f(a1,b1);
    c2 = c2f(args->n,a1,a2,b2);
    e1 = e1f(a1,c1);
    e2 = e2f(a1,a2,c2);
    printf("a1: %.4f\n",a1);
    printf("a2: %.4f\n",a2);
    printf("b1: %.4f\n",b1);
    printf("b2: %.4f\n",b2);
    printf("c1: %.4f\n",c1);
    printf("c2: %.4f\n",c2);
    printf("e1: %.4f\n",e1);
    printf("e2: %.4f\n",e2);
  }
  return 0;
}
